InstanceInvokeMetaCapability class

Gives support for reflective invocation of instance members (methods, getters, and setters) annotated with instances of metadataType or a subtype thereof.

Inheritance
Implementers

Constructors

InstanceInvokeMetaCapability(Type metadataType)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
metadataType → Type
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited