ReflectableNoSuchMethodError class

Thrown when a method is invoked via a reflectable, but the reflectable doesn't have the capabilities to invoke it.

Inheritance
Implemented types

Constructors

ReflectableNoSuchMethodError(Object? receiver, String memberName, List positionalArguments, Map<Symbol, dynamic>? namedArguments, StringInvocationKind kind)

Properties

hashCode → int
The hash code for this object.
no setterinherited
invocation → StringInvocation
no setter
kind → StringInvocationKind
final
memberName → String
final
namedArguments → Map<Symbol, dynamic>?
namedArguments is nullable because invoke and similar methods on mirrors allow their namedArguments parameter to be null. It specifies that there are no named arguments.
final
positionalArguments → List
final
receiver → Object?
receiver is nullable because (1) we can reflect on the null object and hence it can be the receiver, (2) a static method invocation uses the reflected type as the receiver, but null is used when no capability was requested for the reflected type, and (3) a top-level function uses null as the receiver.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited