ReflecteeQuantifyCapability class abstract

Abstract superclass for all capability classes supporting quantification over the set of potential reflectees.

The quantifying capability classes are capable of recieving a list of up to ten ApiReflectCapability arguments in a varargs style (just a comma separated list of arguments, rather than enclosing them in <ApiReflectCapability>[]). When even more than ten arguments are needed, the fromList constructor should be used.

Implemented types
Implementers

Constructors

ReflecteeQuantifyCapability()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited