MethodMirror class abstract

A MethodMirror reflects a Dart language function, method, constructor, getter, or setter.

Implemented types

Constructors

MethodMirror()

Properties

constructorName → String
The constructor name for named constructors and factory methods.
no setter
dynamicReflectedReturnType → Type
If hasDynamicReflectedReturnType is true, returns the corresponding Type as specified for dynamicReflectedType in ClassMirror. Otherwise, an UnsupportedError is thrown.
no setter
hasDynamicReflectedReturnType → bool
Returns the value specified with hasDynamicReflectedType in ClassMirror, but for the return type given by the annotation of the method modeled by this mirror.
no setter
hashCode → int
Override requested by linter.
no setteroverride
hasReflectedReturnType → bool
Returns the value specified with hasReflectedType in TypeMirror, but for the return type given by the annotation of the method modeled by this mirror.
no setter
isAbstract → bool
Is the reflectee abstract?
no setter
isConstConstructor → bool
Is the reflectee a const constructor?
no setter
isConstructor → bool
Is the reflectee a constructor?
no setter
isFactoryConstructor → bool
Is the reflectee a factory constructor?
no setter
isGenerativeConstructor → bool
Is the reflectee a generative constructor?
no setter
isGetter → bool
Is the reflectee a getter?
no setter
isOperator → bool
Is the reflectee an operator?
no setter
isPrivate → bool
Whether this declaration is library private.
no setterinherited
isRedirectingConstructor → bool
Is the reflectee a redirecting constructor?
no setter
isRegularMethod → bool
Is the reflectee a regular function or method?
no setter
isSetter → bool
Is the reflectee a setter?
no setter
isStatic → bool
A function is considered non-static iff it is permited to refer to 'this'.
no setter
isSynthetic → bool
Returns true if the reflectee is synthetic, and returns false otherwise.
no setter
isTopLevel → bool
Whether this declaration is top-level.
no setterinherited
location → SourceLocation
The source location of this Dart language entity, or null if the entity is synthetic.
no setterinherited
metadata → List<Object>
A list of the metadata associated with this declaration.
no setterinherited
owner → DeclarationMirror
A mirror on the owner of this Dart language entity.
no setteroverride
parameters → List<ParameterMirror>
A list of mirrors on the parameters for the reflectee.
no setter
qualifiedName → String
The fully-qualified name for this Dart language entity.
no setterinherited
reflectedReturnType → Type
If hasReflectedReturnType is true, returns the corresponding Type. Otherwise, an UnsupportedError is thrown.
no setter
returnType → TypeMirror
A mirror on the return type for the reflectee.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
simpleName → String
The simple name for this Dart language entity.
no setterinherited
source → String?
The source code for the reflectee, if available. Otherwise null.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
Whether this mirror is equal to other.
override