StringInvocation class abstract

Used to describe the invocation when a no-such-method situation arises. We need to use this variant of the standard Invocation class, because we have no access to the Symbol for the memberName.

Constructors

StringInvocation()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAccessor → bool
no setter
isGetter → bool
no setter
isMethod → bool
no setter
isSetter → bool
no setter
memberName → String
no setter
namedArguments → Map<Symbol, dynamic>
no setter
positionalArguments → List
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited